@@ -1,10 +1,10 @@
 package Email::Send::Sendmail;
-# $Id: Sendmail.pm,v 1.2 2004/07/08 16:40:05 cwest Exp $
+# $Id: Sendmail.pm,v 1.3 2004/07/20 22:11:46 cwest Exp $
 use strict;
 
 use vars qw[$VERSION $SENDMAIL];
-$VERSION  = (qw$Revision: 1.2 $)[1];
-$SENDMAIL = q[sendmail];
+$VERSION  = (qw$Revision: 1.3 $)[1];
+$SENDMAIL ||= q[sendmail];
 
 sub send {
     my ($message, @args) = @_;
